-- name: [CS] Kirby
-- description: Write blurb/description here!\n\n\\#ff7777\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation


]]

local TEXT_MOD_NAME = "Kirby"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("star_kirby_geo") -- Located in "actors"

local TEX_KIRBY_ICON = get_texture_info("render1") -- Located in "textures"

-- All Located in "sound" Name them whatever you want. Remember to include the .ogg extension
local VOICETABLE_CHARNAME2 = {
    --[CHAR_SOUND_OKEY_DOKEY] = 'hai.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'hai.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'huh.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'hyu.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'houh.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'jump.ogg', 'jump.ogg', 'jump.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = 'jump.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'hyu.ogg', 'hai.ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] = 'huh.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'Silent.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'Silent.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'Silent.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = 'hyu.ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'huh.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'tyoy.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'Silent.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'scream.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'houh.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'Silent.ogg', 
	[CHAR_SOUND_HRMM] = 'hyu.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = 'star.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'hai.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = 'huh.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'Silent.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = 'scream.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'Silent.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'Silent.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'snore.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'snore2.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'snore2.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'Silent.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'Silent.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'Silent.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = 'scream.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'Silent.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'yayay.ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_CHAR = {
    normal = smlua_model_util_get_id("FILENAME_geo"),
    wing = smlua_model_util_get_id("FILENAME_geo"),
    metal = smlua_model_util_get_id("FILENAME_geo"),
}

local PALETTE_CHAR = {
    [PANTS]  = "FF87A7",
    [SHIRT]  = "FF1939",
    [GLOVES] = "ffffff",
    [SHOES]  = "FF1939",
    [HAIR]   = "FF87A7",
    [SKIN]   = "FF87A7",
    [CAP]    = "FF1939",
	[EMBLEM] = "FF87A7"
}

local CSloaded = false
local function on_character_select_load()
    CT_CHARNAME2 = _G.charSelect.character_add("Kirby", {"Description/Info", "Description/Info"}, "Chrrli", {r = 255, g = 135, b = 167}, E_MODEL_CUSTOM_MODEL, CT_CHARNAME2, TEX_KIRBY_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_CHARNAME2)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CHARNAME2, HM_CHARNAME2)

	_G.charSelect.character_hook_moveset(1, HOOK_MARIO_UPDATE, mario_update)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CHARNAME2 then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CHARNAME2 then return _G.charSelect.voice.snore(m) end
end

function mario_update(m)
	if not _G.charSelectExists then return end
    if _G.charSelect.character_get_life_icon(0) ~= TEX_KIRBY_ICON then return end
    if m.pos.y <= m.floorHeight + 1250 then
		if m.action == ACT_JUMP and m.controller.buttonPressed & A_BUTTON ~= 0 then
			m.vel.y = 60
			set_mario_action(m, ACT_JUMP, 0)
			m.faceAngle.y = m.intendedYaw
		end
	end
	if m.pos.y >= m.floorHeight + 1200 then
		if m.action == ACT_JUMP and m.controller.buttonPressed & A_BUTTON ~= 0 then
			m.vel.y = 0
			set_mario_action(m, ACT_TRIPLE_JUMP, 0)
			m.faceAngle.y = m.intendedYaw
		end
	end
	if m.action == ACT_GROUND_POUND_LAND and m.controller.buttonPressed & B_BUTTON ~= 0 then
		set_mario_action(m, ACT_SLIDE_KICK, 0)
		mario_set_forward_vel(m, 55)
		m.faceAngle.y = m.intendedYaw
	end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)
hook_event(HOOK_MARIO_UPDATE, mario_update)